<?php
/**
 * Element Conference Theme page
 *
 * @package Element Conference
 */

if ( ! defined( 'ELEMENTO_CONFERENCE_DOCS' ) ) {
	define( 'ELEMENTO_CONFERENCE_DOCS', 'http://www.wpelemento.com/theme-documentation/elemento-conference/' );
}
if ( ! defined( 'ELEMENTO_CONFERENCE_SUPPORT' ) ) {
	define( 'ELEMENTO_CONFERENCE_SUPPORT', 'https://wordpress.org/support/theme/elemento-conference/' );
}
if ( ! defined( 'ELEMENTO_CONFERENCE_REVIEW' ) ) {
	define( 'ELEMENTO_CONFERENCE_REVIEW', 'https://wordpress.org/support/theme/elemento-conference/reviews/#new-post' );
}
if ( ! defined( 'ELEMENTO_CONFERENCE_LIVE_DEMO' ) ) {
	define( 'ELEMENTO_CONFERENCE_LIVE_DEMO', 'https://www.wpelemento.com/demo/elementor-conference/' );
}
if ( ! defined( 'ELEMENTO_CONFERENCE_BUY_NOW' ) ) {
	define( 'ELEMENTO_CONFERENCE_BUY_NOW', 'https://www.wpelemento.com/elementor/elementor-conference-wordpress-theme/' );
}

//Admin Enqueue for Admin
function elemento_conference_admin_enqueue_scripts(){
	wp_enqueue_style('elemento-conference-admin-style', esc_url( get_template_directory_uri() ) . '/includes/about-theme/css/admin.css');
}
add_action( 'admin_enqueue_scripts', 'elemento_conference_admin_enqueue_scripts' );

/**
 * Add theme page
 */
function elemento_conference_menu() {
	add_theme_page( esc_html__( 'About Theme', 'elemento-conference' ), esc_html__( 'About Theme', 'elemento-conference' ), 'edit_theme_options', 'elemento-conference-about', 'elemento_conference_about_display' );
}
add_action( 'admin_menu', 'elemento_conference_menu' );

/**
 * Display About page
 */
function elemento_conference_about_display() {
	$theme = wp_get_theme(); ?>
	<div class="wrap about-wrap full-width-layout">
		<div class="about-theme">
			<h1><?php echo esc_html( $theme ); ?></h1>
			<div class="theme-description">
				<p class="about-text">
					<?php
					// Remove last sentence of description.
					$description = explode( '. ', $theme->get( 'Description' ) );

					array_pop( $description );

					$description = implode( '. ', $description );

					echo esc_html( $description . '.' );
				?></p>
			</div>
		</div>

		<?php
			elemento_conference_main_screen();
		?>

		<div class="return-to-dashboard">
			<?php if ( current_user_can( 'update_core' ) && isset( $_GET['updated'] ) ) : ?>
				<a href="<?php echo esc_url( self_admin_url( 'update-core.php' ) ); ?>">
					<?php is_multisite() ? esc_html_e( 'Return to Updates', 'elemento-conference' ) : esc_html_e( 'Return to Dashboard &rarr; Updates', 'elemento-conference' ); ?>
				</a> |
			<?php endif; ?>
			<a href="<?php echo esc_url( self_admin_url() ); ?>"><?php is_blog_admin() ? esc_html_e( 'Go to Dashboard &rarr; Home', 'elemento-conference' ) : esc_html_e( 'Go to Dashboard', 'elemento-conference' ); ?></a>
		</div>
	</div>
	<?php
}

/**
 * Output the main about screen.
 */
function elemento_conference_main_screen() {
	$theme = wp_get_theme(); ?>
	<div class="feature-section">
		<div class="card">
			<h2 class="title"><?php esc_html_e( 'Theme Customizer', 'elemento-conference' ); ?></h2>
			<p><?php esc_html_e( 'Easy Customization options are available on custumizer screen.', 'elemento-conference' ) ?></p>
			<p><a href="<?php echo esc_url( admin_url( 'customize.php' ) ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'Customize', 'elemento-conference' ); ?></a></p>
		</div>

		<div class="card">
			<h2 class="title"><?php esc_html_e( 'Documentation', 'elemento-conference' ); ?></h2>
			<p><?php esc_html_e( 'Here is our step by step documentation to help you out in create your website using our theme.', 'elemento-conference' ) ?></p>
			<p><a href="<?php echo esc_url( ELEMENTO_CONFERENCE_DOCS ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'Documentation', 'elemento-conference' ); ?></a></p>
		</div>

		<div class="card">
			<h2 class="title"><?php esc_html_e( 'Support', 'elemento-conference' ); ?></h2>
			<p><?php esc_html_e( 'Get quick support from genuine people who deliver tailored solutions to your questions.', 'elemento-conference' ) ?></p>
			<p><a href="<?php echo esc_url( ELEMENTO_CONFERENCE_SUPPORT ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'Support', 'elemento-conference' ); ?></a></p>
		</div>

		<div class="card">
			<h2 class="title"><?php esc_html_e( 'Review', 'elemento-conference' ); ?></h2>
			<p><?php esc_html_e( 'Show us support by reveiwing our theme. Click here to leave your reveiw.', 'elemento-conference' ) ?></p>
			<p><a href="<?php echo esc_url( ELEMENTO_CONFERENCE_REVIEW ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'Review', 'elemento-conference' ); ?></a></p>
		</div>
	</div>
	<div class="pro-feature-section">
		<h2 class="title"><?php esc_html_e( 'Elemento Conference Pro', 'elemento-conference' ); ?></h2>
		<div class="pro-buttons">
			<a href="<?php echo esc_url( ELEMENTO_CONFERENCE_LIVE_DEMO ); ?>" class="button button-primary live-preview" target="_blank"><?php esc_html_e( 'Live Preview', 'elemento-conference' ); ?></a>
			<a href="<?php echo esc_url( ELEMENTO_CONFERENCE_BUY_NOW ); ?>" class="button button-primary buy-nw" target="_blank"><?php esc_html_e( 'Buy Now', 'elemento-conference' ); ?></a>
		</div>
		<img src="<?php echo esc_url( $theme->get_screenshot() ); ?>" />
	</div>
	<?php
}
